#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gitit
version:              0.15.1.2
visibility:           public
id:                   gitit-0.15.1.2-3J54ZGRnklr6fLdRBSBVIh
key:                  gitit-0.15.1.2-3J54ZGRnklr6fLdRBSBVIh
license:              LicenseRef-GPL
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
stability:            experimental
synopsis:             Wiki using happstack, git or darcs, and pandoc.
description:
    Gitit is a wiki backed by a git, darcs, or mercurial
    filestore.  Pages and uploaded files can be modified either
    directly via the VCS'\''s command-line tools or through
    the wiki'\''s web interface. Pandoc is used for markup
    processing, so pages may be written in
    (extended) markdown, reStructuredText, LaTeX, HTML,
    or literate Haskell.

    Notable features include

    * plugins: dynamically loaded page
    transformations written in Haskell (see
    "Network.Gitit.Interface")

    * conversion of TeX math to MathML for display in
    web browsers

    * syntax highlighting of source code
    files and code snippets

    * Atom feeds (site-wide and per-page)

    * a library, "Network.Gitit", that makes it simple
    to include a gitit wiki in any happstack application

    For usage information:  @gitit --help@

category:             Network
abi:                  ca43a07853a8201fb2b1feb09515204e
exposed:              True
exposed-modules:
    Network.Gitit Network.Gitit.Authentication
    Network.Gitit.Authentication.Github Network.Gitit.Cache
    Network.Gitit.Compat.Except Network.Gitit.Config
    Network.Gitit.ContentTransformer Network.Gitit.Feed
    Network.Gitit.Framework Network.Gitit.Handlers
    Network.Gitit.Initialize Network.Gitit.Interface
    Network.Gitit.Layout Network.Gitit.Page Network.Gitit.Plugins
    Network.Gitit.Rpxnow Network.Gitit.Server Network.Gitit.State
    Network.Gitit.Types Network.Gitit.Util Paths_gitit

import-dirs:          /usr/lib/ghc-9.6.6/site-local/gitit-0.15.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gitit-0.15.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gitit-0.15.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/gitit
hs-libraries:         HSgitit-0.15.1.2-3J54ZGRnklr6fLdRBSBVIh
depends:
    HStringTemplate-0.8.8-K7lXfHoTNeF7dMzjsJ02Of
    HTTP-4000.4.1-DUNXrgKdKkOEL7h0Dnjqi
    SHA-1.6.4.4-KRZJCS52poaHfqPlW5b8Sg
    aeson-2.2.1.0-B4RqQZAnAt5HkJbmyrGfNz base-4.18.2.1
    base64-bytestring-1.2.1.0-KFieoz0Zw8V2RvHGFxevKT
    blaze-html-0.9.2.0-LSAimzELNao5dnqqHv2z4j bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.8.5
    doctemplates-0.11.0.1-2TM6YxZkc8KEoedApkDW1h
    feed-1.3.2.1-aFjGm0uJWdKNoFQZvpRLA filepath-1.4.300.1
    filestore-0.6.5.1-7aRLrYqj4TI7hshr5H5Erf ghc-9.6.6
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    happstack-server-7.9.3-DsNg5LNmk8U7VodIt7RpIm
    hoauth2-2.14.0-BoBU34FMAVdIBKODNShldu
    hslogger-1.3.2.0-KhhAW8rWjeZEGkIjuDbYCZ
    http-client-tls-0.3.6.4-Jmopvhh6XJdDm7pjT39Fiq
    http-conduit-2.3.9.1-DWFgRdsPwHeLMuXLLTLH6k
    json-0.10-5cbleOMoqrB4Hh1v10DibR mtl-2.3.1
    network-3.1.4.0-75tKhCALOXaIm7EtXFkhVT
    network-bsd-2.8.1.0-AeecyAJsOb61EizTfO0xBy
    network-uri-2.6.4.2-I9XioeQOOP5Ac2FpC6EX17
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    old-time-1.1.0.4-3lD0LwNFkdkGhWCMuxpBlx
    pandoc-3.5-DeGCBEjNqyN4mE7DBAiiPQ
    pandoc-types-1.23.1-95l8XBmSHT2GBM5NwgapTe parsec-3.1.16.1
    pretty-1.1.3.6 process-1.6.19.0
    random-1.2.1.3-FMSvagGpt1yKb93FcA32lH
    recaptcha-0.1.0.4-Bq0ZVN6hEtO52OA0qnpBAf
    safe-0.3.21-5upUC2HDQExLGQDqkjmsiV
    skylighting-0.14.4-94fco7bnov3KrzOjt2iljj
    split-0.2.5-AyXT2XodrdlCEAhUVzMUfI syb-0.7.3-KphnMBwMsN4JTFJbKosoKP
    tagsoup-0.14.8-3xQTjlYayNA68vr4JyCXII
    temporary-1.3-9e6Qhr5NsMnAXTtyTxRjlF text-2.0.2 time-1.12.2
    uri-bytestring-0.3.3.1-INOFyaw9GDyFNoeCdRq3hL
    url-2.1.3-FnoMg0Amz5x5iDNEWuwHDq
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv
    uuid-1.3.16-7dtMJHW7vNkAahr5eLmavU xhtml-3000.2.2.1
    xml-1.3.14-3CsuYrgQlhu1X5fBOwcswt
    xml-conduit-1.9.1.4-FAIa9Z3Kz8qB8b9F1OKNRE
    xml-types-0.3.8-ISf6rjkeTjSFXsXdIGBwau
    xss-sanitize-0.3.7.2-Hq02ROkBeZyEDJrFZcN3ns
    zlib-0.7.0.0-5YFD9ZcJbA0LvKM88Z7Iwj

haddock-interfaces:   /usr/share/doc/gitit/html/gitit.haddock
haddock-html:         /usr/share/doc/gitit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

